createPassword method
Creates a secure password based on the master key, index, and order.
masterKey: The master key used for password generation.index: The index value used for generating the password.order: The order in which the password is constructed.
Returns a Future containing the generated password as a String.
Implementation
Future<String> createPassword(
{required String masterKey, required int index, required String order}) {
return BouncyCastleSecurityPlatform.instance
.createPassword(masterKey, index, order);
}