getVersion method

Future<String> getVersion()

Retrieves the version of the Bouncy Castle library being used.

Returns a Future containing the version as a String.

Implementation

Future<String> getVersion() {
  return BouncyCastleSecurityPlatform.instance.getVersion();
}